fintorch.datasets package
=========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   fintorch.datasets.kaggle

Submodules
----------

fintorch.datasets.auctiondata module
------------------------------------

.. automodule:: fintorch.datasets.auctiondata
   :members:
   :undoc-members:
   :show-inheritance:

fintorch.datasets.elliptic module
---------------------------------

.. automodule:: fintorch.datasets.elliptic
   :members:
   :undoc-members:
   :show-inheritance:

fintorch.datasets.ellipticpp module
-----------------------------------

.. automodule:: fintorch.datasets.ellipticpp
   :members:
   :undoc-members:
   :show-inheritance:

fintorch.datasets.invoice module
--------------------------------

.. automodule:: fintorch.datasets.invoice
   :members:
   :undoc-members:
   :show-inheritance:

fintorch.datasets.marketdata module
-----------------------------------

.. automodule:: fintorch.datasets.marketdata
   :members:
   :undoc-members:
   :show-inheritance:

fintorch.datasets.stockticker module
------------------------------------

.. automodule:: fintorch.datasets.stockticker
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: fintorch.datasets
   :members:
   :undoc-members:
   :show-inheritance:
